#include "editdbdialog.h"
#include "ui_editdbdialog.h"

editDBDialog::editDBDialog(QSqlDatabase& db_copy, QWidget *parent) :
    m_db(db_copy),
    QDialog(parent),
    ui(new Ui::editDBDialog)
{
    ui->setupUi(this);
    dialog = new signInDialog(m_db);
    if (!m_db.open())
    {
        QMessageBox::warning(this, "Failed to load database", "Error: " + m_model->lastError().text());
    }
    m_model = new QSqlQueryModel;
    ui->curTableTV->setModel(m_model);
    refresh();
    file.setFileName("logs.txt");
    file.open(QIODevice::ReadWrite);
    ui->queryHistory->setText(file.readAll());
    connect(ui->tablesList, &QListWidget::itemClicked, this, &editDBDialog::selectTable);
}


editDBDialog::editDBDialog(QWidget* parent) :
    QDialog(parent),
    ui(new Ui::editDBDialog)
{
    m_db = QSqlDatabase::addDatabase("QPSQL");
    dialog = new signInDialog(m_db);
    QSettings settings;
    settings.beginGroup("/Database_browser/settings");
    m_db.setDatabaseName(settings.value("Database_name", "fn1131_2021").toString());
    m_db.setHostName(settings.value("Host", "195.19.32.74").toString());
    m_db.setPort(settings.value("Port", 5432).toInt());
    m_db.setUserName(settings.value("Login", "student").toString());
    m_db.setPassword(settings.value("Password", "bmstu").toString());
    settings.endGroup();

    if (!m_db.open())
    {
        QMessageBox::warning(this, "Failed to load database", "Error: " + m_model->lastError().text());
    }
    m_model=new QSqlQueryModel;
    ui->curTableTV->setModel(m_model);
    ui->tablesList->addItems(m_db.tables());

    file.setFileName("logs.txt");
    file.open(QIODevice::ReadWrite);
    ui->queryHistory->setText(file.readAll());
}


editDBDialog::~editDBDialog()
{
    delete ui;
}


void editDBDialog::refresh()
{
   ui->tablesList->clear();
   ui->tablesList->addItems(m_db.tables());
}


void editDBDialog::on_runQueryBtn_clicked()
{
    QString qry_str = ui->queryWnd->toPlainText();
    QSqlQuery *qry = new QSqlQuery(m_db);
    if (qry->exec(qry_str))
    {
        ui->queryHistory->append(qry_str);
        refresh();
        m_model->setQuery(*qry);
        ui->curTableTV->setModel(m_model);
    }
    else
    {
        QMessageBox::warning(this, "Failed to execute query", qry->lastError().text());
    }
}


void editDBDialog::on_clearBtn_clicked()
{
    ui->queryWnd->clear();
}

void editDBDialog::selectTable(QListWidgetItem* item)
{
    QSqlQuery *qry = new QSqlQuery(m_db);
    QString qry_str = "SELECT * FROM ";
    qry_str.append(item->text());
    qry->exec(qry_str);
    m_model->setQuery(*qry);
    ui->curTableTV->setModel(m_model);
}



void editDBDialog::on_changeServerBtn_clicked()
{
    //emit signInWndShow();
    signInDialog signInDial(m_db);
    signInDial.setModal(true);
    signInDial.exec();
}

