#include "mainwindow.h"
#include "signindialog.h"
#include "ui_mainwindow.h"
#include <QDateTime>
#include <QString>

MainWindow::MainWindow(QSqlDatabase& db_copy, QWidget *parent) :
    QMainWindow(parent),
    ui(new Ui::MainWindow)
{
    ui->setupUi(this);
    m_db = db_copy;
    dialog = new signInDialog(m_db);
    if (!m_db.open())
    {
        QMessageBox::warning(this, "Failed to load database", "Error: " + m_model->lastError().text());
    }
    m_model = new QSqlQueryModel;
    ui->curTableTV->setModel(m_model);
    refresh();
    file.setFileName("logs.txt");
    file.open(QIODevice::ReadWrite);
    if (!file.isOpen()){QMessageBox::warning(this, "File open error!", "");}
    ui->queryHistory->setText(file.readAll());
    connect(ui->tablesList, &QListWidget::itemClicked, this, &MainWindow::selectTable);
}


MainWindow::MainWindow(QWidget* parent) :
    QMainWindow(parent),
    ui(new Ui::MainWindow)
{
    ui->setupUi(this);
    m_db = QSqlDatabase::addDatabase("QPSQL");
    dialog = new signInDialog(m_db);
    QSettings settings;
    settings.beginGroup("/Database_browser/settings");
    m_db.setDatabaseName(settings.value("Database_name", "fn1131_2021").toString());
    m_db.setHostName(settings.value("Host", "195.19.32.74").toString());
    m_db.setPort(settings.value("Port", 5432).toInt());
    m_db.setUserName(settings.value("Login", "student").toString());
    m_db.setPassword(settings.value("Password", "bmstu").toString());
    settings.endGroup();

    if (!m_db.open())
    {
        QMessageBox::warning(this, "Failed to load database", "Error: " + m_model->lastError().text());
    }
    m_model = new QSqlQueryModel;
    ui->curTableTV->setModel(m_model);
    refresh();

    file.setFileName("logs.txt");
    file.open(QIODevice::ReadWrite);
    if (!file.isOpen()){QMessageBox::warning(this, "File open error!", "");}
    ui->queryHistory->setText(file.readAll());
    connect(ui->tablesList, &QListWidget::itemClicked, this, &MainWindow::selectTable);
}


MainWindow::~MainWindow()
{
    QTextStream out(&file);
    file.resize(0);
    out << ui->queryHistory->toPlainText();
    file.close();
    delete ui;
}


void MainWindow::refresh()
{
   ui->tablesList->clear();
   ui->tablesList->addItems(m_db.tables());
}


void MainWindow::on_runQueryBtn_clicked()
{
    QString qry_str = ui->queryWnd->toPlainText();
    QSqlQuery *qry = new QSqlQuery(m_db);
    if (qry->exec(qry_str))
    {
        ui->queryHistory->append(qry_str);
        refresh();
        m_model->setQuery(*qry);
        ui->curTableTV->setModel(m_model);
    }
    else
    {
        QMessageBox::warning(this, "Failed to execute query", "Correct the query and try again.");
    }
}


void MainWindow::on_clearBtn_clicked()
{
    ui->queryWnd->clear();
}

void MainWindow::selectTable(QListWidgetItem* item)
{
    QSqlQuery *qry = new QSqlQuery(m_db);
    QString qry_str = "SELECT * FROM ";
    qry_str.append(item->text());
    qry->exec(qry_str);
    m_model->setQuery(*qry);
    ui->curTableTV->setModel(m_model);
}



void MainWindow::on_changeServerBtn_clicked()
{
    QTextStream out(&file);
    file.resize(0);
    out << ui->queryHistory->toPlainText();
    dialog->show();
    show();
    refresh();
}


void MainWindow::on_clearHistoryBtn_clicked()
{
    ui->queryHistory->setText("");
    file.resize(0);
}

